#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
#' @useDynLib wkutils, .registration = TRUE
#' @importFrom Rcpp sourceCpp
#' @import wk
## usethis namespace: end
NULL
